@@ -275,7 +275,7 @@ qx.Class.define("callbackery.ui.form.Auto", {
         this);
 
         var formWgt = new (formRenderer)(form);
-        var fl = formWgt.getLayout();
+        //var fl = formWgt.getLayout();
 
         this._add(formWgt);
     },
